@@ -15,10 +15,14 @@ import importlib
 import filecmp
 import itertools
 from shutil import rmtree, which
+import json
+import requests
+from packaging import version
 
 # local import
 from dotdrop.logger import Logger
 from dotdrop.exceptions import UnmetDependency
+from dotdrop.version import __version__ as VERSION
 
 LOG = Logger()
 STAR = '*'
@@ -217,6 +221,8 @@ def strip_home(path):
 
 def must_ignore(paths, ignores, debug=False):
     """return true if any paths in list matches any ignore patterns"""
+    if debug:
+        LOG.dbg('must_ignore called', force=True)
     if not ignores:
         return False
     if debug:
@@ -233,10 +239,14 @@ def must_ignore(paths, ignores, debug=False):
                     LOG.dbg('ignore \"{}\" match: {}'.format(i, path),
                             force=True)
                 ignore_matches.append(path)
+
         # Then remove any matches that actually shouldn't be ignored
         for nign in ignored_negative:
             # Each of these will start with an '!' so we need to remove that
             nign = nign[1:]
+            if debug:
+                msg = 'trying to match :\"{}\" with non-ignore-pattern:\"{}\"'
+                LOG.dbg(msg.format(path, nign))
             if fnmatch.fnmatch(path, nign):
                 if debug:
                     msg = 'negative ignore \"{}\" match: {}'.format(nign, path)
@@ -252,6 +262,8 @@ def must_ignore(paths, ignores, debug=False):
                              'previous ignore pattern.'.format(nign)
                              )
         if ignore_matches:
+            if debug:
+                LOG.dbg('ignoring {}'.format(paths), force=True)
             return True
     if debug:
         LOG.dbg('NOT ignoring {}'.format(paths), force=True)
@@ -447,3 +459,22 @@ def debug_dict(title, elems, debug):
                 LOG.dbg('\t\t- {}'.format(i))
         else:
             LOG.dbg('\t- \"{}\": {}'.format(k, val))
+
+
+def check_version():
+    """check dotdrop version on github and compare with current"""
+    url = 'https://api.github.com/repos/deadc0de6/dotdrop/releases/latest'
+    req = requests.get(url, timeout=1)
+    if not req:
+        return
+    try:
+        latest = req.json()['name']
+    except json.decoder.JSONDecodeError:
+        return
+    except ValueError:
+        return
+    if latest.startswith('v'):
+        latest = latest[1:]
+    if version.parse(VERSION) < version.parse(latest):
+        msg = 'A new version of dotdrop is available ({})'
+        LOG.warn(msg.format(latest))
